@@ -1,51 +1,21 @@
 {package POEx::Role::SessionInstantiation;
-our $VERSION = '0.092673';
-}
-
+$POEx::Role::SessionInstantiation::VERSION = '1.100910';}
 use MooseX::Declare;
 
 #ABSTRACT: A Moose Role for turning objects into POE Sessions
 
 
-role POEx::Role::SessionInstantiation
+role POEx::Role::SessionInstantiation with MooseX::CompileTime::Traits
 {
-    use MooseX::Types::Moose(':all');
-    use MooseX::Types::Structured(':all');
-
-    use aliased 'POEx::Role::Event', 'Event';
-
     with 'POEx::Role::SessionInstantiation::Meta::Session::Magic';
     with 'POEx::Role::SessionInstantiation::Meta::Session::Implementation';
     with 'POEx::Role::SessionInstantiation::Meta::Session::Events';
     with 'POEx::Role::SessionInstantiation::Meta::Session::Sugar';
-
-    # enable traits via import
-    method import (ClassName $role: ArrayRef :$traits?)
-    {
-        if(defined($traits))
-        {
-            my $tc = Tuple[RoleName, Optional[HashRef]];
-            
-            unless($tc->validate($traits))
-            {
-                with $traits->[0], $traits->[1];
-                return;
-            }
-
-            foreach my $tuple (@$traits)
-            {
-                my $ret = $tc->validate($tuple);
-                die $ret if defined($ret);
-                with $tuple->[0] => $tuple->[1];
-            }
-        }
-    }
 }
 1;
 
 
 
-
 =pod
 
 =head1 NAME
@@ -54,13 +24,22 @@ POEx::Role::SessionInstantiation - A Moose Role for turning objects into POE Ses
 
 =head1 VERSION
 
-version 0.092673
+version 1.100910
+
+=head1 DESCRIPTION
+
+POEx::Role::SessionInstantiation provides a nearly seamless integration for 
+non-POE objects into a POE environment. It does this by handling the POE stuff
+behind the scenes including allowing per instances method changes, session 
+registration to the Kernel, and providing some defaults like setting an alias
+if supplied via the attribute or constructor argument, or defining a _default
+that warns if your object receives an event that it does not have.
+
+This role exposes your class' methods as POE events.
 
 =head1 SYOPSIS
 
     package My::Class;
-our $VERSION = '0.092673';
-
     use 5.010;
     use MooseX::Declare;
 
@@ -112,19 +91,6 @@ our $VERSION = '0.092673';
     # Still need to call ->run();
     POE::Kernel->run();
 
-
-
-=head1 DESCRIPTION
-
-POEx::Role::SessionInstantiation provides a nearly seamless integration for 
-non-POE objects into a POE environment. It does this by handling the POE stuff
-behind the scenes including allowing per instances method changes, session 
-registration to the Kernel, and providing some defaults like setting an alias
-if supplied via the attribute or constructor argument, or defining a _default
-that warns if your object receives an event that it does not have.
-
-This role exposes your class' methods as POE events.
-
 =head1 NOTES
 
 Like all dangerous substances, this Role needs a big fat warning. It should be
@@ -174,7 +140,7 @@ inside the after 'BUILD' advice, and also during event handler changes from POE
 the moral to this? If you need to overload "", !=, or == in your composed class
 things will likely break. You have been warned.
 
-=back 
+=back
 
 So please heed the warnings and don't blame me if this summons the terrasque 
 into your datacenter and you left your +5 gear at home.
@@ -196,7 +162,7 @@ First let's declare a role that frobinates something at start:
     role FrobAtStart
     {
         with 'POEx::Role::SessionInstantiation::Meta::Session::Events';
-
+        
         has frobinator =>
         (
             is => 'ro', 
@@ -246,30 +212,18 @@ Now let's use them
         # need to make sure these are loaded 
         use FrobinateAtStart;
         use SomeLogger;
-
+        
         # and now the magic
         use POEx::Role::SessionInstantiation 
-            traits => [ ['FrobAtStart'], ['SomeLogger' => { foo => 'log' } ] ];
-
+            traits => [ 'FrobAtStart', SomeLogger => { foo => 'log' } ];
+        
         # compose it now that it has traits applied
         with 'POEx::Role::SessionInstantiation';
         ...
     }
 
-And here is the import method signature:
-
-    method import (RoleName $role: ArrayRef :$traits?)
-
-Where $traits is expected to contain a series of Tuples that look like:
-
-    Tuple[RoleName, Optional[HashRef]]
-
-And there is a special case for a single trait where $traits is the tuple that
-is defined above. So the use statement above, if there is a single trait,
-could have been written as:
-
-    use POEx::Role::SessionInstantiation
-        traits => [ 'MyTrait' => { key => $args } ];
+For more information on how this mechanism works, please see
+MooseX::CompileTime::Traits
 
 =head2 WRITING YOUR OWN TRAITS
 
@@ -296,7 +250,7 @@ This role holds the delegated methods from POE::Kernel (post, yield, call)
 And this is the implementation piece that implements the POE::Session
 interface that lets POE interact with our sessions
 
-=back 
+=back
 
 Please see their POD for more details on the inner workings of this module.
 
@@ -306,14 +260,12 @@ Please see their POD for more details on the inner workings of this module.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2009 by Nicholas Perez.
+This software is copyright (c) 2010 by Nicholas Perez.
 
-This is free software, licensed under:
-
-  The GNU General Public License, Version 3, June 2007
-
-=cut 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
+=cut
 
 
 __END__
