@@ -1,7 +1,4 @@
-{package MyTrait;
-our $VERSION = '0.092673';
-}
-
+{package MyTrait;}
 use MooseX::Declare;
 
 role MyTrait(Str :$attr = 'blarg')
